@@ -5,7 +5,7 @@
 from typing import Callable
 
 import httplib2
-from apiclient.discovery import build
+from googleapiclient.discovery import build
 from oauth2client.service_account import ServiceAccountCredentials
 
 
@@ -21,6 +21,9 @@ class BaseGAV4Reader:
         (3) Return an iterable of the get_report method
         (4) Iterate until no pagination token is found. A.k.a. pageToken==None
     """
+    analytics = None
+    max_pages = None
+
     class ReaderIter:
         """Inner Class - Iterator that yields queries until max pages or pageToken == None."""
         page_counter = 0
@@ -35,7 +38,7 @@ class BaseGAV4Reader:
         ):
             self.query_fn = query_fn
             self.max_pages = kwargs.get("max_pages", None)
-            self.pageToken = page_token
+            self.page_token = page_token
             self.query = query
 
         def __iter__(self):
@@ -52,14 +55,15 @@ class BaseGAV4Reader:
                 if self.page_counter >= self.max_pages:
                     print("stopping iteration on max pages = {}".format(self.max_pages))
                     raise StopIteration
-            if self.page_counter > 0 and self.pageToken is None:
-                print("stopping iteration on pageToken = {}".format(self.pageToken))
+
+            if self.page_counter > 0 and self.page_token is None:
+                print("stopping iteration on pageToken = {}".format(self.page_token))
                 raise StopIteration
 
             # run get_report
-            report, self.pageToken = self.query_fn(
+            report, self.page_token = self.query_fn(
                 queries=self.query,
-                page_token=self.pageToken
+                page_token=self.page_token
             )
             print(
                 'Finished query function for page {page} of view ID {view_id}'.format(
@@ -68,31 +72,12 @@ class BaseGAV4Reader:
                 )
             )
 
+            # increment pagination counter
+            self.page_counter += 1
+
             return report
 
-    def __init__(self, **kwargs):
-        self.max_pages = kwargs.get('max_pages', None)
-        # # create authenticator
-        self.credentials = self.auth_credentials()  # auth credentials method to be implemented
-        # # build analytics service object
-        self.build_analytics_service_object()
-        NotImplementedError("Must implement your own init method in class")
-
-    def auth_credentials(self, **kwargs):
-        """Get a service that communicates to a Google API.
-        Args:
-            api_name: The name of the api to connect to.
-            api_version: The api version to connect to.
-            scope: A list auth scopes to authorize for the application.
-            key_file_location: The path to a valid service account p12 key file.
-            service_account_email: The service account email address.
-        Returns:
-            A service that is connected to the specified API.
-        """
-        # set up your authentication here
-        credentials = None
-        return credentials
-
+    # pylint: disable=no-member
     def build_analytics_service_object(
             self,
             api_name: str = 'analyticsreporting',
@@ -111,7 +96,11 @@ class BaseGAV4Reader:
         # Build the service object.
         return build(api_name, api_version, http=http)
 
-    def get_report(self, queries: list, page_token: str = None):
+    def get_report(
+            self,
+            queries: list,
+            page_token: str = None
+    ):
         """
             Use the Analytics Service Object to query the Analytics Reporting API V4.
 
@@ -124,8 +113,8 @@ class BaseGAV4Reader:
 
         """
         if page_token is not None:
-            for q in queries:
-                q.update({'page_token':page_token})
+            for query in queries:
+                query.update({'page_token':page_token})
 
         # run batch query
         report = self.analytics.reports().batchGet(body={
@@ -134,7 +123,7 @@ class BaseGAV4Reader:
 
         return report, page_token
 
-    def run_query(self, query: list, pageToken: str = None):
+    def run_query(self, query: list, page_token: str = None):
         """
             returns a sync iterator
         """
@@ -142,7 +131,7 @@ class BaseGAV4Reader:
             query_fn=self.get_report,
             query=query,
             max_pages=self.max_pages,
-            pageToken=pageToken)
+            page_token=page_token)
         return iter_
 
 
@@ -150,6 +139,8 @@ class CustomGoogleAnalyticsReaderWithServiceAcc(BaseGAV4Reader):
     """
         Custom Google Analytics Reader which authenticates with Service account
     """
+
+    # pylint: disable=super-init-not-called
     def __init__(
             self,
             service_account_secrets_path: str,
@@ -163,8 +154,8 @@ class CustomGoogleAnalyticsReaderWithServiceAcc(BaseGAV4Reader):
         # build analytics object
         self.analytics = self.build_analytics_service_object()
 
+    @staticmethod
     def auth_credentials(
-            self,
             service_account_secrets_path,
             service_account_email,
             scopes
